****************
REST Connections
****************
REST API Connections are used for communication with various network controllers, vedor-specific APIs and network devices, which support this method of communication.


.. toctree::
   :maxdepth: 3

   RestBase
   ApicEmBase